@@ -16,16 +16,16 @@ public:
 
 protected:
 
-  void on_print(int a);
+  virtual void on_print(int a);
   
-  typedef sigc::signal<void, int> type_signal_print;
+  using type_signal_print = sigc::signal<void, int>;
   type_signal_print signal_print;
     
 };
 
 Something::Something()
 {
-  auto iter = signal_print.connect( sigc::mem_fun(*this, &Something::on_print) );
+  auto iter = signal_print.connect( sigc::mem_fun(this, &Something::on_print) );
 
   signal_print.emit(2);
 
@@ -36,7 +36,7 @@ Something::Something()
 
 void Something::on_print(int a)
 {
-  std::cout << "on_print received: " << a << std::endl;
+  std::cout << "on_print recieved: " << a << std::endl;
 }
 
 int main()
