@@ -21,14 +21,14 @@
 
 #include <sigc++config.h>
 #include <sigc++/trackable.h>
-#include <sigc++/functors/functor_trait.h>
+#include <sigc++/functors/functor_base.h>
 
 namespace sigc
 {
 
 namespace internal {
 
-typedef void* (*hook)(void*);
+using hook = void* (*)(void*);
 
 /** Internal representation of a slot.
  * Derivations of this class can be considered as a link
@@ -63,6 +63,7 @@ struct SIGC_API slot_rep : public trackable
   /* NB: Instead of slot_rep we could inherit slot_base from trackable.
    * However, a simple benchmark seems to indicate that this slows
    * down dereferencing of slot list iterators. Martin. */
+  //TODO: Try this now? murrayc.
 
   /// Callback that invokes the contained functor.
   /* This can't be a virtual function since number of arguments
@@ -75,20 +76,24 @@ struct SIGC_API slot_rep : public trackable
   /* This could be a replaced by a virtual dtor. However since this struct is
    * crucual for the efficiency of the whole library we want to avoid this.
    */
-  hook destroy_;
+  func_destroy_notify destroy_;
 
+  using hook_dup = slot_rep* (*)(slot_rep*);
+
+private:
   /** Callback that makes a deep copy of the slot_rep object.
    * @return A deep copy of the slot_rep object.
    */
-  hook dup_;
+  hook_dup dup_;
 
+public:
   /** Callback of parent_. */
-  hook cleanup_;
+  func_destroy_notify cleanup_;
 
   /** Parent object whose callback cleanup_ is executed on notification. */
-  void* parent_;
+  notifiable* parent_;
 
-  inline slot_rep(hook call__, hook destroy__, hook dup__) noexcept
+  inline slot_rep(hook call__, notifiable::func_destroy_notify destroy__, hook_dup dup__) noexcept
     : call_(call__), destroy_(destroy__), dup_(dup__), cleanup_(nullptr), parent_(nullptr) {}
 
   inline ~slot_rep()
@@ -116,7 +121,7 @@ struct SIGC_API slot_rep : public trackable
    * @param parent The new parent.
    * @param cleanup The callback to execute from notify().
    */
-  inline void set_parent(void* parent, hook cleanup) noexcept
+  inline void set_parent(notifiable* parent, notifiable::func_destroy_notify cleanup) noexcept
     {
       parent_ = parent;
       cleanup_ = cleanup;
@@ -132,7 +137,7 @@ struct SIGC_API slot_rep : public trackable
    * referred object dying.
    * @param data The slot_rep object that is becoming invalid (@p this).
    */
-  static void* notify(void* data);
+  static void notify(notifiable* data);
 };
 
 /** Functor used to add a dependency to a trackable.
@@ -182,52 +187,33 @@ struct SIGC_API slot_do_unbind
  * A slot can be constructed from any function object or function, regardless of
  * whether it is a global function, a member method, static, or virtual.
  *
- * @section slots-creating Creating Slots
- *
- * Use the sigc::mem_fun() or sigc::ptr_fun() template functions to get a sigc::slot, like so:
+ * Use the sigc::mem_fun() and sigc::ptr_fun() template functions to get a sigc::slot, like so:
  * @code
- * sigc::slot<void(int)> sl = sigc::mem_fun(someobj, &SomeClass::somemethod);
+ * sigc::slot<void, int> sl = sigc::mem_fun(someobj, &SomeClass::somemethod);
  * @endcode
  * or
  * @code
- * sigc::slot<void(int)> sl = sigc::ptr_fun(&somefunction);
+ * sigc::slot<void, int> sl = sigc::ptr_fun(&somefunction);
  * @endcode
  * or, in gtkmm,
  * @code
  * m_Button.signal_clicked().connect( sigc::mem_fun(*this, &MyWindow::on_button_clicked) );
  * @endcode
- * Alternatively, you may use this deprecated syntax:
- * @code
- * sigc::slot<void, int> sl = sigc::mem_fun(someobj, &SomeClass::somemethod);
- * @endcode
  *
  * The compiler will complain if SomeClass::somemethod, etc. have the wrong signature.
  *
  * You can also pass slots as method parameters where you might normally pass a function pointer.
  *
- * @section slots-auto-disconnect Member Methods and Automatic Disconnection
- *
- * See @ref mem_fun "sigc::mem_fun()" about deriving from sigc::trackable to prevent member
- * methods from being called after the instance has been destroyed.
- *
- * @section slots-auto auto
- *
  * sigc::mem_fun() and sigc::ptr_fun() return functors, but those functors are
  * not slots.
  * @code
- * sigc::slot<void(int)> sl = sigc::mem_fun(someobj, &SomeClass::somemethod);
+ * sigc::slot<void, int> sl = sigc::mem_fun(someobj, &SomeClass::somemethod);
  * @endcode
  * is not equivalent to
  * @code
  * auto sl = sigc::mem_fun(someobj, &SomeClass::somemethod); // Not a slot!
  * @endcode
  *
- * If you don't explicitly use a sigc::slot then the slot could call a method
- * on an instance after it has been destroyed even if the method is in a class
- * that derives from sigc::trackable.
- *
- * @section slots-with-lambdas C++ Lambdas
- *
  * A C++11 lambda expression is a functor (function object). It is automatically
  * wrapped in a slot, if it is connected to a signal.
  * @code
@@ -241,11 +227,10 @@ struct SIGC_API slot_do_unbind
  *
  * If you connect a C++11 lambda expression or a std::function<> instance to
  * a signal or assign it to a slot,
- * - with libsigc++ versions before 2.6, if the return type is not void,
+ * - With libsigc++ versions before 2.6, if the return type is not void,
      you must use the #SIGC_FUNCTORS_DEDUCE_RESULT_TYPE_WITH_DECLTYPE macro,
  * - if your functor contains references to sigc::trackable derived objects,
- *   those objects will not be tracked, unless you also use sigc::track_object()
- *   or sigc::track_obj().
+ *   those objects will not be tracked, unless you also use sigc::track_obj().
  *
  * @ingroup sigcfunctors
  */
@@ -267,7 +252,7 @@ struct SIGC_API slot_do_unbind
  */
 class SIGC_API slot_base : public functor_base
 {
-  typedef internal::slot_rep rep_type;
+  using rep_type = internal::slot_rep;
 
   // Move operations are not declared noexcept because
   // 1. they may copy instead of move
@@ -304,6 +289,8 @@ public:
    */
   explicit operator bool() const noexcept;
 
+  using func_destroy_notify = notifiable::func_destroy_notify;
+
   /** Sets the parent of this slot.
    * This function is used by signals to register a notification callback.
    * This notification callback is executed when the slot becomes invalid
@@ -311,21 +298,22 @@ public:
    * @param parent The new parent.
    * @param cleanup The notification callback.
    */
-  void set_parent(void* parent, void* (*cleanup)(void*)) const noexcept;
+  void set_parent(notifiable* parent, notifiable::func_destroy_notify cleanup) const noexcept;
+
+
 
-  typedef trackable::func_destroy_notify func_destroy_notify;
   /** Add a callback that is executed (notified) when the slot is detroyed.
    * This function is used internally by connection objects.
    * @param data Passed into func upon notification.
    * @param func Callback executed upon destruction of the object.
    */
-  void add_destroy_notify_callback(void* data, func_destroy_notify func) const;
+  void add_destroy_notify_callback(notifiable* data, notifiable::func_destroy_notify func) const;
 
   /** Remove a callback previously installed with add_destroy_notify_callback().
    * The callback is not executed.
    * @param data Parameter passed into previous call to add_destroy_notify_callback().
    */
-  void remove_destroy_notify_callback(void* data) const;
+  void remove_destroy_notify_callback(notifiable* data) const;
 
   /** Returns whether the slot is invalid.
    * @return @p true if the slot is invalid (empty).
