@@ -42,14 +42,21 @@ namespace internal
  * erase() to sweep() when the signal is being emitted. sweep() removes all
  * invalid slots from the list.
  */
-struct SIGC_API signal_impl
+struct SIGC_API signal_impl : public notifiable
 {
-  typedef std::size_t size_type;
-  typedef std::list<slot_base> slot_list;
-  typedef slot_list::iterator       iterator_type;
-  typedef slot_list::const_iterator const_iterator_type;
+  using size_type = std::size_t;
+  using slot_list = std::list<slot_base>;
+  using iterator_type = slot_list::iterator;
+  using const_iterator_type = slot_list::const_iterator;
 
   signal_impl();
+  ~signal_impl();
+
+  signal_impl(const signal_impl& src) = delete;
+  signal_impl& operator=(const signal_impl& src) = delete;
+
+  signal_impl(signal_impl&& src) = delete;
+  signal_impl& operator=(signal_impl&& src) = delete;
 
   // only MSVC needs this to guarantee that all new/delete are executed from the DLL module
 #ifdef SIGC_NEW_DELETE_IN_LIBRARY_ONLY
@@ -58,11 +65,11 @@ struct SIGC_API signal_impl
 #endif
 
   /// Increments the reference counter.
-  inline void reference()
+  inline void reference() noexcept
     { ++ref_count_; }
 
   /// Increments the reference and execution counter.
-  inline void reference_exec()
+  inline void reference_exec() noexcept
     { ++ref_count_; ++exec_count_; }
 
   /** Decrements the reference counter.
@@ -84,7 +91,7 @@ struct SIGC_API signal_impl
   /** Returns whether the list of slots is empty.
    * @return @p true if the list of slots is empty.
    */
-  inline bool empty() const
+  inline bool empty() const noexcept
     { return slots_.empty(); }
 
   /// Empties the list of slots.
@@ -93,14 +100,14 @@ struct SIGC_API signal_impl
   /** Returns the number of slots in the list.
    * @return The number of slots in the list.
    */
-  size_type size() const;
+  size_type size() const noexcept;
 
   /** Returns whether all slots in the list are blocked.
    * @return @p true if all slots are blocked or the list is empty.
    *
    * @newin{2,4}
    */
-  bool blocked() const;
+  bool blocked() const noexcept;
 
   /** Sets the blocking state of all slots in the list.
    * If @e should_block is @p true then the blocking state is set.
@@ -112,7 +119,7 @@ struct SIGC_API signal_impl
    *
    * @newin{2,4}
    */
-  void block(bool should_block = true);
+  void block(bool should_block = true) noexcept;
 
   /** Adds a slot at the bottom of the list of slots.
    * @param slot_ The slot to add to the list of slots.
@@ -120,6 +127,14 @@ struct SIGC_API signal_impl
    */
   iterator_type connect(const slot_base& slot_);
 
+  /** Adds a slot at the bottom of the list of slots.
+   * @param slot_ The slot to add to the list of slots.
+   * @return An iterator pointing to the new slot in the list.
+   *
+   * @newin{2,8}
+   */
+  iterator_type connect(slot_base&& slot_);
+
   /** Adds a slot at the given position into the list of slots.
    * @param i An iterator indicating the position where @p slot_ should be inserted.
    * @param slot_ The slot to add to the list of slots.
@@ -127,6 +142,15 @@ struct SIGC_API signal_impl
    */
   iterator_type insert(iterator_type i, const slot_base& slot_);
 
+  /** Adds a slot at the given position into the list of slots.
+   * @param i An iterator indicating the position where @p slot_ should be inserted.
+   * @param slot_ The slot to add to the list of slots.
+   * @return An iterator pointing to the new slot in the list.
+   *
+   * @newin{2,8}
+   */
+  iterator_type insert(iterator_type i, slot_base&& slot_);
+
   /** Removes the slot at the given position from the list of slots.
    * @param i An iterator pointing to the slot to be removed.
    * @return An iterator pointing to the slot in the list after the one removed.
@@ -144,7 +168,7 @@ struct SIGC_API signal_impl
    * erase() to sweep() when the signal is being emitted.
    * @param d A local structure, created in insert().
    */
-  static void* notify(void* d);
+  static void notify(notifiable* d);
 
   /** Reference counter.
    * The object is destroyed when @em ref_count_ reaches zero.
@@ -172,7 +196,7 @@ struct SIGC_API signal_exec
   /** Increments the reference and execution counter of the parent sigc::signal_impl object.
    * @param sig The parent sigc::signal_impl object.
    */
-  inline signal_exec(const signal_impl* sig)
+  inline signal_exec(const signal_impl* sig) noexcept
     : sig_(const_cast<signal_impl*>(sig) )
     { sig_->reference_exec(); }
 
@@ -191,9 +215,9 @@ struct SIGC_API signal_exec
  */
 struct temp_slot_list
 {
-  typedef signal_impl::slot_list slot_list;
-  typedef signal_impl::iterator_type iterator;
-  typedef signal_impl::const_iterator_type const_iterator;
+  using slot_list = signal_impl::slot_list;
+  using iterator = signal_impl::iterator_type;
+  using const_iterator = signal_impl::const_iterator_type;
 
   temp_slot_list(slot_list &slots) : slots_(slots)
   {
@@ -241,7 +265,7 @@ private:
  * class MyClass
  * {
  * public:
- *   typedef sigc::signal<void> MySignalType;
+ *   using MySignalType = sigc::signal<void>;
  *   MySignalType get_my_signal() { return m_my_signal; }
  * private:
  *   MySignalType m_my_signal;
@@ -278,24 +302,24 @@ private:
  */
 struct SIGC_API signal_base : public trackable
 {
-  typedef std::size_t size_type;
+  using size_type = std::size_t;
 
-  signal_base();
+  signal_base() noexcept;
 
-  signal_base(const signal_base& src);
+  signal_base(const signal_base& src) noexcept;
 
-  signal_base(signal_base&& src) noexcept;
+  signal_base(signal_base&& src);
 
   ~signal_base();
 
   signal_base& operator=(const signal_base& src);
 
-  signal_base& operator=(signal_base&& src) noexcept;
+  signal_base& operator=(signal_base&& src);
 
   /** Returns whether the list of slots is empty.
    * @return @p true if the list of slots is empty.
    */
-  inline bool empty() const
+  inline bool empty() const noexcept
     { return (!impl_ || impl_->empty()); }
 
   /// Empties the list of slots.
@@ -304,14 +328,14 @@ struct SIGC_API signal_base : public trackable
   /** Returns the number of slots in the list.
    * @return The number of slots in the list.
    */
-  size_type size() const;
+  size_type size() const noexcept;
 
   /** Returns whether all slots in the list are blocked.
    * @return @p true if all slots are blocked or the list is empty.
    *
    * @newin{2,4}
    */
-  bool blocked() const;
+  bool blocked() const noexcept;
 
   /** Sets the blocking state of all slots in the list.
    * If @e should_block is @p true then the blocking state is set.
@@ -324,16 +348,16 @@ struct SIGC_API signal_base : public trackable
    *
    * @newin{2,4}
    */
-  void block(bool should_block = true);
+  void block(bool should_block = true) noexcept;
 
   /** Unsets the blocking state of all slots in the list.
    *
    * @newin{2,4}
    */
-  void unblock();
+  void unblock() noexcept;
 
 protected:
-  typedef internal::signal_impl::iterator_type iterator_type;
+  using iterator_type = internal::signal_impl::iterator_type;
 
   /** Adds a slot at the end of the list of slots.
    * With connect(), slots can also be added during signal emission.
@@ -343,6 +367,16 @@ protected:
    */
   iterator_type connect(const slot_base& slot_);
 
+  /** Adds a slot at the end of the list of slots.
+   * With connect(), slots can also be added during signal emission.
+   * In this case, they won't be executed until the next emission occurs.
+   * @param slot_ The slot to add to the list of slots.
+   * @return An iterator pointing to the new slot in the list.
+   *
+   * @newin{2,8}
+   */
+  iterator_type connect(slot_base&& slot_);
+
   /** Adds a slot at the given position into the list of slots.
    * Note that this function does not work during signal emission!
    * @param i An iterator indicating the position where @e slot_ should be inserted.
@@ -351,6 +385,16 @@ protected:
    */
   iterator_type insert(iterator_type i, const slot_base& slot_);
 
+  /** Adds a slot at the given position into the list of slots.
+   * Note that this function does not work during signal emission!
+   * @param i An iterator indicating the position where @e slot_ should be inserted.
+   * @param slot_ The slot to add to the list of slots.
+   * @return An iterator pointing to the new slot in the list.
+   *
+   * @newin{2,8}
+   */
+  iterator_type insert(iterator_type i, slot_base&& slot_);
+
   /** Removes the slot at the given position from the list of slots.
    * Note that this function does not work during signal emission!
    * @param i An iterator pointing to the slot to be removed.
