@@ -17,14 +17,10 @@ int ident(int i)
 template<typename T>
 struct min_accum
 {
-  typedef T result_type;
+  using result_type = T;
 
   template<class I>
-#ifndef SIGC_HAVE_SUN_REVERSE_ITERATOR
   typename std::iterator_traits<I>::value_type operator()(I i1, I i2)
-#else
-  typename I::value_type operator()(I i1, I i2)
-#endif
   {
     return *std::min_element(i1, i2);
   }
@@ -39,7 +35,7 @@ int main(int argc, char* argv[])
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 
-  sigc::signal0<int,min_accum<int> > signal;
+  sigc::signal<int>::accumulated<min_accum<int>> signal;
 
   signal.connect(sigc::bind(sigc::ptr_fun(ident), 3));
   signal.connect(sigc::bind(sigc::ptr_fun(ident), 1));
