@@ -15,13 +15,11 @@
 
 namespace
 {
-
-TestUtilities* util = nullptr;
 std::ostringstream result_stream;
 
 struct arithmetic_mean_accumulator
 {
-  typedef double result_type;
+  using result_type = double;
   template<typename T_iterator>
   double operator()(T_iterator first, T_iterator last) const
   {
@@ -36,7 +34,7 @@ struct arithmetic_mean_accumulator
 template<class Ret>
 struct vector_accumulator
 {
-  typedef std::vector<Ret> result_type;
+  using result_type = std::vector<Ret>;
   template<typename T_iterator>
   result_type operator()(T_iterator first, T_iterator last) const
   {
@@ -71,26 +69,32 @@ struct A : public sigc::trackable
   }
 };
 
-void test_empty_signal()
+} // end anonymous namespace
+
+int main(int argc, char* argv[])
 {
-  sigc::signal<int,int>::accumulated<arithmetic_mean_accumulator> sig;
-  sigc::signal<int,int>::accumulated<vector_accumulator<int> > sig_vec;
+  auto util = TestUtilities::get_instance();
+
+  if (!util->check_command_args(argc, argv))
+    return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
+
+   sigc::signal<int,int>::accumulated<arithmetic_mean_accumulator> sig;
+   sigc::signal<int,int>::accumulated<vector_accumulator<int> > sig_vec;
 
   result_stream << "Result (empty slot list): " << sig(0);
   util->check_result(result_stream, "Result (empty slot list): -1");
   result_stream << "Vector result (empty slot list): "
                 << (sig_vec(0).empty() ? "empty" : "not empty");
   util->check_result(result_stream, "Vector result (empty slot list): empty");
-}
-
-void test_mean()
-{
-  sigc::signal<int,int>::accumulated<arithmetic_mean_accumulator> sig;
 
   A a;
-  sig.connect(sigc::ptr_fun1(&foo));
-  sig.connect(sigc::mem_fun1(a, &A::foo));
-  sig.connect(sigc::ptr_fun1(&bar));
+  sig.connect(sigc::ptr_fun(&foo));
+  sig.connect(sigc::mem_fun(&a, &A::foo));
+  sig.connect(sigc::ptr_fun(&bar));
+
+  sig_vec.connect(sigc::ptr_fun(&foo));
+  sig_vec.connect(sigc::mem_fun(&a, &A::foo));
+  sig_vec.connect(sigc::ptr_fun(&bar));
 
   double dres = sig(1);
   result_stream << "Mean accumulator: Result (i=1): "
@@ -103,17 +107,7 @@ void test_mean()
                 << std::fixed << std::setprecision(3) << dres;
   util->check_result(result_stream,
     "foo: 34, A::foo: 206, bar: 52, Mean accumulator: Plain Result (i=11): 97.333");
-}
 
-void test_vector_accumulator()
-{
-  sigc::signal<int,int>::accumulated<vector_accumulator<int> > sig_vec;
-
-  A a;
-  sig_vec.connect(sigc::ptr_fun(&foo));
-  sig_vec.connect(sigc::mem_fun(a, &A::foo));
-  sig_vec.connect(sigc::ptr_fun(&bar));
-  
   auto res1 = sig_vec(1);
   result_stream << "Vector accumulator: Result (i=1): ";
   for (auto num : res1)
@@ -127,20 +121,6 @@ void test_vector_accumulator()
     result_stream << num << " ";
   util->check_result(result_stream,
     "foo: 10, A::foo: 46, bar: 12, Vector accumulator: Result (i=3): 10 46 12 ");
-}
-
-} // end anonymous namespace
-
-int main(int argc, char* argv[])
-{
-  util = TestUtilities::get_instance();
-
-  if (!util->check_command_args(argc, argv))
-    return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
-
-  test_empty_signal();
-  test_mean();
-  test_vector_accumulator();
 
   return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 }
