@@ -1,6 +1,7 @@
 #include "testutilities.h"
 #include <sigc++/sigc++.h>
 #include <sstream>
+#include <functional> //For std::ref().
 #include <cstdlib>
 
 namespace
@@ -34,23 +35,23 @@ public:
 
 int main(int argc, char* argv[])
 {
-  TestUtilities* util = TestUtilities::get_instance();
+  auto util = TestUtilities::get_instance();
 
   if (!util->check_command_args(argc, argv))
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 
-  Derived* instance = new Derived();
+  auto instance = new Derived();
   sigc::slot<void> handler = sigc::mem_fun(instance, &Derived::method);
   handler();
   util->check_result(result_stream, "method()");
 
-  sigc::slot<void> param =
-    sigc::bind(sigc::slot<void, Derived&>(), sigc::ref(*instance));
+  auto param =
+    sigc::bind(sigc::slot<void, Derived&>(), std::ref(*instance));
   param();
   util->check_result(result_stream, "");
 
-  sigc::slot<Derived> ret =
-    sigc::bind_return(sigc::slot<void>(), sigc::ref(*instance));
+  auto ret =
+    sigc::bind_return(sigc::slot<void>(), std::ref(*instance));
   ret();
   util->check_result(result_stream, "");
 
