@@ -17,22 +17,22 @@
  */
 
 // The purpose of this test case is threefold.
-// - Test sigc::track_obj() and sigc::track_object().
+// - Test sigc::track_obj().
 // - Show that a slot with a C++11 lambda expression can be automatically
 //   disconnected when an object derived from sigc::trackable is deleted,
-//   provided sigc::track_obj() or sigc::track_object() is used.
-//   It shows that C++11 lambda expressions can replace the libsigc++ lambda
-//   expressions, which have been removed.
+//   provided sigc::track_obj() is used.
+//   It's shown here as a preparation for deprecating and eventually
+//   deleting the libsigc++ lambda expressions.
 //   See https://bugzilla.gnome.org/show_bug.cgi?id=672555
 // - Test the code example in the documentation in sigc++/adaptors/track_obj.h.
 //
+// To test the C++11 lambda expressions with gcc 4.6.3 (and probably some later
+// versions of gcc; gcc 4.7.x also understands -std=c++11):
+//   make CXXFLAGS='-g -O2 -std=c++0x' test_track_obj
+//   ./test_track_obj
+//   echo $?
 // If test_track_obj writes nothing and the return code is 0, the test has passed.
 
-// sigc::track_obj() is deprecated, but let's keep the test if possible.
-// If libsigc++ is configured with -Dbuild-deprecated-api=false
-// (--disable-deprecated-api), SIGCXX_DISABLE_DEPRECATED is defined in
-// sigc++config.h. An undef at the start of this file has no effect.
-#undef SIGCXX_DISABLE_DEPRECATED
 
 #include "testutilities.h"
 #include <string>
@@ -42,6 +42,7 @@
 #include <sigc++/adaptors/track_obj.h>
 #include <sigc++/signal.h>
 
+
 namespace
 {
 std::ostringstream result_stream;
@@ -61,7 +62,7 @@ struct bar_group4 : public sigc::trackable
 class Functor1 : public sigc::functor_base
 {
 public:
-  typedef std::string result_type;
+  using result_type = std::string;
 
   Functor1(const bar_group4& bar)
   : bar_(bar) {}
@@ -71,15 +72,14 @@ public:
     return (i<0) ? "negative" : ((i>0) ? "positive" : "zero");
   }
 
-protected:
-  // Don't make it private. clang++ does not like unused private data.
+private:
   const bar_group4& bar_;
 };
 
 class Functor2 : public sigc::functor_base
 {
 public:
-  typedef std::string result_type;
+  using result_type = std::string;
 
   Functor2(const bar_group4& bar, const book& aBook)
   : bar_(bar), aBook_(aBook) {}
@@ -92,10 +92,8 @@ public:
     return result;
   }
 
-protected:
-  // Don't make it private. clang++ does not like unused private data.
-  const bar_group4& bar_;
 private:
+  const bar_group4& bar_;
   const book& aBook_;
 };
 
@@ -129,105 +127,74 @@ int main(int argc, char* argv[])
     return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 
   sigc::slot<std::string, int> sl1;
-  sigc::slot<std::string, int> sl2;
   {
     bar_group4 bar4;
-#ifndef SIGCXX_DISABLE_DEPRECATED
     sl1 = sigc::track_obj(Functor1(bar4), bar4);
-#else
-    sl1 = sigc::track_object(Functor1(bar4), bar4);
-#endif
-    sl2 = sigc::track_object(Functor1(bar4), bar4);
-    result_stream << sl1(-2) << ", " << sl2(2);
-    util->check_result(result_stream, "negative, positive");
+    result_stream << sl1(-2);
+    util->check_result(result_stream, "negative");
 
-  } // auto-disconnect sl1 and sl2
+  } // auto-disconnect sl1
 
-  result_stream << sl1(-2) << ", " << sl2(2);
-  util->check_result(result_stream, ", ");
+  result_stream << sl1(-2);
+  util->check_result(result_stream, "");
 
   // Allocate on the heap. valgrind can then find erroneous memory accesses.
   // (There should be none, of course.)
-  auto psl3 = new sigc::slot<std::string, int, std::string>;
-  auto psl4 = new sigc::slot<std::string, int, std::string>;
+  auto psl2 = new sigc::slot<std::string, int, std::string>;
   bar_group4* pbar4 = new bar_group4;
   book* pbook4 = new book("A Book");
-#ifndef SIGCXX_DISABLE_DEPRECATED
-  *psl3 = sigc::track_obj(Functor2(*pbar4, *pbook4), *pbar4, *pbook4);
-#else
-  *psl3 = sigc::track_object(Functor2(*pbar4, *pbook4), *pbar4, *pbook4);
-#endif
-  *psl4 = sigc::track_object(Functor2(*pbar4, *pbook4), *pbar4, *pbook4);
-  result_stream << (*psl3)(0, "Book title: ") << ", " << (*psl4)(1, "Title: ");
-  util->check_result(result_stream, "zero, Book title: A Book, positive, Title: A Book");
+  *psl2 = sigc::track_obj(Functor2(*pbar4, *pbook4), *pbar4, *pbook4);
+  result_stream << (*psl2)(0, "Book title: ");
+  util->check_result(result_stream, "zero, Book title: A Book");
 
-  delete pbook4; // auto-disconnect *psl3 and *psl4
+  delete pbook4; // auto-disconnect *psl2
   pbook4 = nullptr;
-  result_stream << (*psl3)(0, "Book title: ") << ", " << (*psl4)(1, "Title: ");
-  util->check_result(result_stream, ", ");
-  delete psl3;
-  psl3 = nullptr;
-  delete psl4;
-  psl4 = nullptr;
+  result_stream << (*psl2)(0, "Book title: ");
+  util->check_result(result_stream, "");
+  delete psl2;
+  psl2 = nullptr;
   delete pbar4;
   pbar4 = nullptr;
 
-  // C++11 lambda expressions:
+
+//C++11 lambda expressions:
 
   // auto-disconnect
   // If you want to auto-disconnect a slot with a C++11 lambda expression
   // that contains references to sigc::trackable-derived objects, you must use
-  // sigc::track_obj() or sigc::track_object().
-  sigc::slot<void, std::ostringstream&> sl11;
-  sigc::slot<void, std::ostringstream&> sl12;
+  // sigc::track_obj().
+  sigc::slot<void, std::ostringstream&> sl10;
   {
     book guest_book("karl");
     // sl1 = [&guest_book](std::ostringstream& stream){ stream << guest_book << "\n"; }; // no auto-disconnect
-#ifndef SIGCXX_DISABLE_DEPRECATED
-    sl11 = sigc::track_obj(
-      [&guest_book](std::ostringstream& stream) { stream << guest_book; }, guest_book);
-#else
-    sl11 = sigc::track_object(
-      [&guest_book](std::ostringstream& stream) { stream << guest_book; }, guest_book);
-#endif
-    sl12 = sigc::track_object(
-      [&guest_book](std::ostringstream& stream) { stream << guest_book; }, guest_book);
-    sl11(result_stream);
-    sl12(result_stream);
-    util->check_result(result_stream, "karlkarl");
+    sl10 = sigc::track_obj([&guest_book](std::ostringstream& stream){ stream << guest_book; }, guest_book);
+    sl10(result_stream);
+    util->check_result(result_stream, "karl");
 
-  } // auto-disconnect sl11 and sl12
+  } // auto-disconnect sl10
 
-  sl11(result_stream);
-  sl12(result_stream);
+  sl10(result_stream);
   util->check_result(result_stream, "");
 
   // auto-disconnect
-  sigc::slot<void> sl21;
-  sigc::slot<void> sl22;
+  sigc::slot<void> sl20;
   {
     book guest_book("karl");
     // sl2 = [&guest_book] () { egon(guest_book); }; // no auto-disconnect
     // sl2 = std::bind(&egon, std::ref(guest_book)); // does not compile (gcc 4.6.3)
-#ifndef SIGCXX_DISABLE_DEPRECATED
-    sl21 = sigc::track_obj([&guest_book]() { egon(guest_book); }, guest_book);
-#else
-    sl21 = sigc::track_object([&guest_book]() { egon(guest_book); }, guest_book);
-#endif
-    sl22 = sigc::track_object([&guest_book]() { egon(guest_book); }, guest_book);
-    sl21();
-    sl22();
-    util->check_result(result_stream, "egon(string 'karl')egon(string 'egon was here')");
+    sl20 = sigc::track_obj([&guest_book] () { egon(guest_book); }, guest_book);
+    sl20();
+    util->check_result(result_stream, "egon(string 'karl')");
 
     result_stream << static_cast<const std::string&>(guest_book);
     util->check_result(result_stream, "egon was here");
 
-  } // auto-disconnect sl21 and sl22
+  } // auto-disconnect sl20
 
-  sl21();
-  sl22();
+  sl20();
   util->check_result(result_stream, "");
 
+
   // Code example in the documentation sigc++/adaptors/macros/track_obj.h.m4
   // -----------------------------------------------------------------------
   {
@@ -235,18 +202,13 @@ int main(int argc, char* argv[])
     sigc::signal<void> some_signal;
     {
       bar_group4 some_bar;
-      //some_signal.connect(sigc::group(&foo,std::ref(some_bar)));
+      //some_signal.connect(sigc::group(&foo, std::ref(some_bar)));
       // disconnected automatically if some_bar goes out of scope
       //some_signal.connect([&some_bar](){ foo_group4(some_bar); }); // no auto-disconnect
       //some_signal.connect(sigc::bind(&foo_group4, std::ref(some_bar))); // auto-disconnects, but we prefer C++11 lambda
-#ifndef SIGCXX_DISABLE_DEPRECATED
       some_signal.connect(sigc::track_obj([&some_bar](){ foo_group4(some_bar); }, some_bar));
-#else
-      some_signal.connect(sigc::track_object([&some_bar](){ foo_group4(some_bar); }, some_bar));
-#endif
-      some_signal.connect(sigc::track_object([&some_bar](){ foo_group4(some_bar); }, some_bar));
       some_signal.emit();
-      util->check_result(result_stream, "foo_group4(bar_group4&)foo_group4(bar_group4&)");
+      util->check_result(result_stream, "foo_group4(bar_group4&)");
 
     } // auto-disconnect the lambda expression
 
@@ -254,5 +216,6 @@ int main(int argc, char* argv[])
     util->check_result(result_stream, "");
   }
 
+
   return util->get_result_and_delete_instance() ? EXIT_SUCCESS : EXIT_FAILURE;
 }
